@@ -21,7 +21,7 @@
 #ifndef GLOM_BACKEND_POSTGRES_SELF_H
 #define GLOM_BACKEND_POSTGRES_SELF_H
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h>
 
 #include <libglom/connectionpool_backends/postgres.h>
 
@@ -70,9 +70,7 @@ private:
 
   virtual Glib::RefPtr<Gnome::Gda::Connection> connect(const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error);
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool create_database(const Glib::ustring& database_name, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<Glib::Error>& error);
-#endif
 
 private:
   /** Examine ports one by one, starting at @a starting_port, in increasing
@@ -85,6 +83,14 @@ private:
   //bool directory_exists_filepath(const std::string& filepath);
   bool directory_exists_uri(const std::string& uri);
 
+  /** Run the command-line with the --version option to discover what version 
+   * of PostgreSQL is installed, so we can use the appropriate configuration 
+   * options when self-hosting.
+   */
+  Glib::ustring get_postgresql_utils_version(const SlotProgress& slot_progress);
+
+  float get_postgresql_utils_version_as_number(const SlotProgress& slot_progress);
+
   std::string m_self_hosting_data_uri;
   int m_port;
   bool m_network_shared;
