@@ -21,7 +21,7 @@
 
 #include <libglom/libglom_config.h> // For HAVE_STRPTIME
 
-#include "glomconversions.h"
+#include <libglom/data_structure/glomconversions.h>
 #include <libglom/connectionpool.h>
 #include <libglom/utils.h>
 
@@ -55,9 +55,12 @@ namespace
 namespace Glom
 {
 
-// Increase the number of digits (even before the decimal point) we can 
-// have until it uses the awkward e syntax. The default seems to be 7
-static const int STRINGSTREAM_PRECISION_DEFAULT = 15;
+
+int Conversions::get_stringstream_precision_default()
+{
+    static const int stringstream_precision_default = 15;
+    return stringstream_precision_default;
+}
 
 Glib::ustring Conversions::format_time(const tm& tm_data)
 {
@@ -431,12 +434,21 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       {
         //Increase the number of digits (even before the decimal point) we can 
         //have until it uses the awkward e syntax. The default seems to be 7.
-        another_stream << std::setprecision(STRINGSTREAM_PRECISION_DEFAULT);
+        another_stream << std::setprecision( NumericFormat::get_default_precision() );
       }
 
       if(!(numeric_format.m_currency_symbol.empty()))
       {
-        another_stream << numeric_format.m_currency_symbol << " ";
+        std::string charset;
+        Glib::get_charset(charset);
+        Glib::ustring currency_symbol = Glib::convert_with_fallback(numeric_format.m_currency_symbol, charset, "UTF-8");
+        // Uses convert_with_fallback(.) for the curreny symbol to avoid an
+        // exception where the operator<<'s automatic conversion fails.
+        // Incompatible encodings are possible since the currency symbol itself
+        // is stored in the Glom document (UTF-8), whereas the stream encoding
+        // depends on the user's locale (needed for the numeric value
+        // representation).
+        another_stream << currency_symbol << " ";
       }
     }
 
@@ -593,7 +605,9 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
 
     std::stringstream clocale_stream;
     clocale_stream.imbue( std::locale::classic() ); //The C locale.
-    clocale_stream << std::setprecision(STRINGSTREAM_PRECISION_DEFAULT); //Avoid the e syntax. Normally this happens afer 7 digits, with loss of precision. TODO: Handle more.
+
+    //Avoid the e syntax. Normally this happens afer 7 digits, with loss of precision. TODO: Handle more.
+    clocale_stream << std::setprecision( NumericFormat::get_default_precision() );
     clocale_stream << the_number;
     const Glib::ustring number_canonical_text = clocale_stream.str(); //Avoid << because it does implicit character conversion (though that might not be a problem here. Not sure). murrayc
     //std::cout << "  DEBUG: number_canonical_text=" << number_canonical_text << std::endl;  
@@ -764,7 +778,7 @@ tm Conversions::parse_time(const Glib::ustring& text, bool& success)
 
 tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale, bool& success)
 {
-  std::cout << "parse_time(): text=" << text << std::endl;
+  //std::cout << "parse_time(): text=" << text << std::endl;
   //The sequence of statements here seems to be very fragile. If you move things then it stops working.
 
   //return parse_tm(text, locale, 'X' /* time */);
