@@ -26,7 +26,7 @@
 
 #include <libglom/python_embed/py_glom_record.h>
 #include <libglom/python_embed/py_glom_related.h>
-#include "pygdavalue_conversions.h" //For pygda_value_as_pyobject().
+#include <libglom/python_embed/pygdavalue_conversions.h> //For pygda_value_as_pyobject().
 
 #include <libglom/data_structure/field.h>
 #include <glibmm/ustring.h>
@@ -56,7 +56,7 @@ Record_init(PyObject *self, PyObject * /* args */, PyObject * /* kwds */)
 {
   PyGlomRecord *self_record = (PyGlomRecord*)self;
 
-  //static char *kwlist[] = {"test", NULL};
+  //static char *kwlist[] = {"test", 0};
 
   //if(!PyArg_ParseTupleAndKeywords(args, kwds, "|i", kwlist,
    //                                 &self->m_test))
@@ -175,7 +175,7 @@ static PyGetSetDef Record_getseters[] = {
     {(char*)"table_name",
      (getter)Record__get_table_name, (setter)0, 0, 0
     },
-    {NULL, 0, 0, 0, 0, }  // Sentinel
+    {0, 0, 0, 0, 0, }  // Sentinel
 };
 
 //Adapt to API changes in Python 2.5:
@@ -211,7 +211,7 @@ Record_tp_as_mapping_getitem(PyObject *self, PyObject *item)
         PyGlomRecord::type_map_field_values::const_iterator iterFind = self_record->m_pMap_field_values->find(key);
         if(iterFind != self_record->m_pMap_field_values->end())
         {
-          return pygda_value_as_pyobject(iterFind->second.gobj(), true /* copy */);
+          return glom_pygda_value_as_pyobject(iterFind->second.gobj(), true /* copy */);
         }
         else
         {
@@ -236,7 +236,7 @@ Record_tp_as_mapping_getitem(PyObject *self, PyObject *item)
 
   g_warning("Record_tp_as_mapping_getitem(): return null.");
   PyErr_SetString(PyExc_IndexError, "field not found");
-  return NULL;
+  return 0;
 }
 
 /*
@@ -256,7 +256,7 @@ static PyMappingMethods Record_tp_as_mapping = {
 
 
 static PyTypeObject pyglom_RecordType = {
-    PyObject_HEAD_INIT(NULL)
+    PyObject_HEAD_INIT(0)
     0,                         /*ob_size*/
     (char*)"glom.Record",             /*tp_name*/
     sizeof(PyGlomRecord), /*tp_basicsize*/
