@@ -60,7 +60,11 @@ void Box_Data_List_Related::enable_buttons()
     get_has_suitable_record_to_view_details() && 
     (m_portal->get_navigation_type() != LayoutItem_Portal::NAVIGATION_NONE);
 
-  m_AddDel.set_allow_view_details(view_details_possible); //Don't allow the user to go to a record in a hidden table.
+  #ifndef GLOM_ENABLE_MAEMO
+  // Don't allow the user to go to a record in a hidden table.
+  // Unless we are on Maemo - then we want to allow editing in a separate window only.
+  m_AddDel.set_allow_view_details(view_details_possible); 
+  #endif //GLOM_ENABLE_MAEMO
 }
 
 bool Box_Data_List_Related::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
@@ -237,7 +241,8 @@ bool Box_Data_List_Related::on_script_button_idle(const Gnome::Gda::Value& prima
 
 void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& primary_key_value)
 {
-  //Note that on_record_added() would only be called on the AddDel itself, so we need ot handle this AddDel signal.
+  //Note that on_record_added() would only be called on the AddDel itself, 
+  //so we need to handle this AddDel signal.
   
   //primary_key_value is a new autogenerated or human-entered key for the row.
   //It has already been added to the database.
@@ -278,26 +283,15 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
     //Create the link by setting the foreign key
     if(m_key_field && m_portal)
     {
-      Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
-      params->add_holder(m_key_field->get_holder(m_key_value));
-      params->add_holder(field_primary_key->get_holder(primary_key_value));
-      Glib::ustring strQuery = "UPDATE \"" + m_portal->get_table_used(Glib::ustring() /* not relevant */) + "\"";
-      strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->get_gda_holder_string();
-      strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->get_gda_holder_string();
-      //std::cout << "Box_Data_List_Related::on_adddel_record_added(): setting value in db=" << primary_key_value.to_string() << std::endl;
-      const bool test = query_execute(strQuery, params);
-      if(test)
-      {
-        //Show it on the view, if it's visible:
-        sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-        layout_item->set_full_field_details(m_key_field);
+      make_record_related(primary_key_value);
+      
+      //Show it on the view, if it's visible:
+      sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+      layout_item->set_full_field_details(m_key_field);
 
-        //TODO: Although the to-field value is visible on the new related record, get_value() returns NULL so you can't immediately navigate to the new record: 
-        //std::cout << "DEBUG: Box_Data_List_Related::on_record_added(): setting field=" << layout_item->get_name() << "m_key_value=" << m_key_value.to_string() << std::endl; 
-        m_AddDel.set_value(row, layout_item, m_key_value);
-      }
-      else
-        std::cerr << "Box_Data_List_Related::on_record_added(): SQL query failed: " << strQuery << std::endl;
+      //TODO: Although the to-field value is visible on the new related record, get_value() returns NULL so you can't immediately navigate to the new record: 
+      //std::cout << "DEBUG: Box_Data_List_Related::on_record_added(): setting field=" << layout_item->get_name() << "m_key_value=" << m_key_value.to_string() << std::endl; 
+      m_AddDel.set_value(row, layout_item, m_key_value);
     }
     else
       std::cerr << "Box_Data_List_Related::on_record_added(): m_key_field is NULL" << std::endl;
@@ -313,7 +307,7 @@ void Box_Data_List_Related::on_adddel_record_added(const Gtk::TreeModel::iterato
 void Box_Data_List_Related::on_dialog_layout_hide()
 {
   Dialog_Layout_List_Related* dialog_related = dynamic_cast<Dialog_Layout_List_Related*>(m_pDialogLayout);
-  g_assert(dialog_related != NULL);
+  g_assert(dialog_related);
   m_portal = dialog_related->get_portal_layout();
 
 
@@ -342,13 +336,13 @@ Dialog_Layout* Box_Data_List_Related::create_layout_dialog() const
     return dialog;
   }
   
-  return NULL;
+  return 0;
 }
 
 void Box_Data_List_Related::prepare_layout_dialog(Dialog_Layout* dialog)
 {
   Dialog_Layout_List_Related* related_dialog = dynamic_cast<Dialog_Layout_List_Related*>(dialog);
-  g_assert(related_dialog != NULL);
+  g_assert(related_dialog);
 
   related_dialog->set_document(m_layout_name, m_layout_platform, get_document(), m_portal, m_parent_table);
 }
@@ -486,6 +480,4 @@ void Box_Data_List_Related::create_layout_add_group(const sharedptr<LayoutGroup>
   }
 }
 
-
-
 } //namespace Glom
