@@ -102,7 +102,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   #else
   std::auto_ptr<Glib::Error> error;
   m_refUIManager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
@@ -227,7 +227,7 @@ void Dialog_RelationshipsOverview::draw_lines()
       Document::type_vec_relationships m_relationships = document->get_relationships(table_name);
       Document::type_vec_fields fields = document->get_table_fields(table_name);
       
-      for(Document::type_vec_relationships::const_iterator rit = m_relationships.begin(); rit != m_relationships.end(); rit++)
+      for(Document::type_vec_relationships::const_iterator rit = m_relationships.begin(); rit != m_relationships.end(); ++rit)
       {
         sharedptr<const Relationship> relationship = *rit;
         if(!relationship)
@@ -489,7 +489,7 @@ void Dialog_RelationshipsOverview::setup_context_menu()
   #else
   std::auto_ptr<Glib::Error> error;
   m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
